import sys

if sys.version_info[:2] >= (3, 8):
    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8`
    from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
else:
    from importlib_metadata import PackageNotFoundError, version  # pragma: no cover

from exception_with_retry.source import ExceptionWithRetry, exception_with_retry

__all__ = ["ExceptionWithRetry", "exception_with_retry"]
try:
    # Change here if project is renamed and does not equal the package name
    dist_name = "exception-with-retry"
    __version__ = version(dist_name)
except PackageNotFoundError:  # pragma: no cover
    __version__ = "unknown"
finally:
    del version, PackageNotFoundError
